searchData={"items":[{"type":"module","title":"Tesla.Middleware.DynamicHeaders","doc":"Set headers dynamically at runtime.\n\nThis is most useful to handle secrets that should not be compiled into the\nrelease.","ref":"Tesla.Middleware.DynamicHeaders.html"},{"type":"module","title":"Options - Tesla.Middleware.DynamicHeaders","doc":"It takes a single option, either a list of tuples or a function.\nThe first element of the tuple is the header name.\nOther values are as follows:\n\n* `{application, key}`: Reads the value from `Application.get_env/2`\n* `{application, key, default}`: Reads the value from `Application.get_env/3`\n* Function with arity 1: Calls the function with the header name to get the value\n* Any other value is passed through as is, same as `Tesla.Middleware.Headers`\n\nIf the option is a zero-arity function, it is called to generate a list of\n`{header_name, value`} tuples.","ref":"Tesla.Middleware.DynamicHeaders.html#module-options"},{"type":"module","title":"Examples - Tesla.Middleware.DynamicHeaders","doc":"```\ndefmodule FooClient do\n  use Tesla\n\n  plug Tesla.Middleware.DynamicHeaders, [\n    {\"X-Foo-Token\", {:my_client, :foo_token}},\n    {\"X-Bar-Token\", {:my_client, :bar_token, \"default\"}},\n    {\"Authorization\", &get_authorization/1}},\n    {\"content/type\", \"application/json\"}\n  ]\n\n  defp get_authorization(header_name) do\n    {header_name, \"token: \"   Application.get_env(:my_client, :auth_token)}\n  end\nend\n```\n\n```\ndefmodule FooClient do\n  use Tesla\n\n  plug Tesla.Middleware.DynamicHeaders, &get_dynamic_headers/0\n\n  defp get_dynamic_headers do\n    Application.get_env(:foo_client, :auth_headers)\n  end\nend\n```","ref":"Tesla.Middleware.DynamicHeaders.html#module-examples"},{"type":"function","title":"Tesla.Middleware.DynamicHeaders.get_header/1","doc":"","ref":"Tesla.Middleware.DynamicHeaders.html#get_header/1"},{"type":"extras","title":"README","doc":"![test workflow](https://github.com/cogini/tesla_middleware_dynamic_headers/actions/workflows/test.yml/badge.svg)\n[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)\n\n# Tesla.Middleware.DynamicHeaders\n\nMiddleware for the [Tesla](https://hexdocs.pm/tesla/readme.html) HTTP client\nthat sets value for HTTP headers dynamically at runtime. \n\nThis is most useful to handle secrets such as auth tokens. If you set them at\ncompile time, then they are hard coded into the release file, which is a\nsecurity risk. Similarly, if you build your code in a CI system, then you have\nto make the secrets available there.","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"Add `tesla_middleware_dynamic_headers` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tesla_middleware_dynamic_headers, \"~> 0.7.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - README","doc":"Add this middleware as a plug in your client.\n\nAdd `plug Tesla.Middleware.DynamicHeaders` to the client and\nspecify the list of dynamic headers. \n\nThe plug takes a single option, either a list of tuples or a function. The\nfirst element of the tuple is the header name. Other values are as follows:\n\n* `{application, key}`: Reads the value from `Application.get_env/2`\n* `{application, key, default}`: Reads the value from `Application.get_env/3`\n* Function with arity 1: Calls the function with the header name to get the value\n* Any other value is passed through as is, same as `Tesla.Middleware.Headers`\n\nIf the option is a zero-arity function, it is called to generate a list of\n`{header_name, value`} tuples.","ref":"readme.html#configuration"},{"type":"extras","title":"Examples - README","doc":"The following example shows configuration via a list of headers:\n\n```elixir\ndefmodule FooClient do\n  use Tesla\n\n  @app :foo_client\n\n  plug(Tesla.Middleware.BaseUrl, \"https://example.com/\")\n\n  plug(Tesla.Middleware.DynamicHeaders, [\n    {\"X-Foo-Token\", {@app, :foo_token}},\n    {\"X-Bar-Token\", {@app, :bar_token, \"default\"}},\n    {\"Authorization\", &get_authorization/1},\n    {\"content/type\", \"application/json\"}\n    ])\n\n  plug(Tesla.Middleware.Logger)\n\n  defp get_authorization(header_name) do\n    {header_name, \"token: \"   Application.get_env(@app, :auth_token)}\n  end\nend\n```\n\nThe following example shows how to use a custom function to generate all the headers:\n\n```\ndefmodule FooClient do\n  use Tesla\n\n  @app :foo_client\n\n  plug Tesla.Middleware.DynamicHeaders, &get_dynamic_headers/0\n\n  defp get_dynamic_headers do\n    Application.get_env(@app, :headers)\n  end\nend\n```\n\nThe equivalent configuration in `config/test.exs` might look like:\n\n```elixir\nconfig :foo_client,\n  foo_token: \"footoken\",\n  bar_token: \"bartoken\",\n  auth_token: \"authtoken\"\n\nconfig :foo_client,\n  headers: [\n    {\"Authorization\", \"token: authtoken\"}\n  ]\n```\n\nIn production, you would set environment variables with the tokens, then read them\nin `config/runtime.exs`:\n\n```elixir\nconfig :foo_client,\n  foo_token: = System.get_env(\"FOO_TOKEN\") || raise \"missing environment variable FOO_TOKEN\"\n```\n\nDocumentation is here: https://hexdocs.pm/tesla_middleware_dynamic_headers\n\nThis project uses the Contributor Covenant version 2.1. Check [CODE_OF_CONDUCT.md](/CODE_OF_CONDUCT.md) for more information.","ref":"readme.html#examples"},{"type":"extras","title":"Changelog","doc":"# Changelog\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.7.0] - 2023-10-08\n#","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Initial version\n\n## [0.7.1] - 2023-10-08\n#","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fix hexdocs link","ref":"changelog.html#fixed"},{"type":"extras","title":"License (Apache 2.0)","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright [yyyy] [name of copyright owner]\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"},{"type":"extras","title":"Code of Conduct","doc":"# Contributor Covenant Code of Conduct","ref":"code_of_conduct.html"},{"type":"extras","title":"Our Pledge - Code of Conduct","doc":"We as members, contributors, and leaders pledge to make participation in our\ncommunity a harassment-free experience for everyone, regardless of age, body\nsize, visible or invisible disability, ethnicity, sex characteristics, gender\nidentity and expression, level of experience, education, socio-economic status,\nnationality, personal appearance, race, caste, color, religion, or sexual\nidentity and orientation.\n\nWe pledge to act and interact in ways that contribute to an open, welcoming,\ndiverse, inclusive, and healthy community.","ref":"code_of_conduct.html#our-pledge"},{"type":"extras","title":"Our Standards - Code of Conduct","doc":"Examples of behavior that contributes to a positive environment for our\ncommunity include:\n\n* Demonstrating empathy and kindness toward other people\n* Being respectful of differing opinions, viewpoints, and experiences\n* Giving and gracefully accepting constructive feedback\n* Accepting responsibility and apologizing to those affected by our mistakes,\n  and learning from the experience\n* Focusing on what is best not just for us as individuals, but for the overall\n  community\n\nExamples of unacceptable behavior include:\n\n* The use of sexualized language or imagery, and sexual attention or advances of\n  any kind\n* Trolling, insulting or derogatory comments, and personal or political attacks\n* Public or private harassment\n* Publishing others' private information, such as a physical or email address,\n  without their explicit permission\n* Other conduct which could reasonably be considered inappropriate in a\n  professional setting","ref":"code_of_conduct.html#our-standards"},{"type":"extras","title":"Enforcement Responsibilities - Code of Conduct","doc":"Community leaders are responsible for clarifying and enforcing our standards of\nacceptable behavior and will take appropriate and fair corrective action in\nresponse to any behavior that they deem inappropriate, threatening, offensive,\nor harmful.\n\nCommunity leaders have the right and responsibility to remove, edit, or reject\ncomments, commits, code, wiki edits, issues, and other contributions that are\nnot aligned to this Code of Conduct, and will communicate reasons for moderation\ndecisions when appropriate.","ref":"code_of_conduct.html#enforcement-responsibilities"},{"type":"extras","title":"Scope - Code of Conduct","doc":"This Code of Conduct applies within all community spaces, and also applies when\nan individual is officially representing the community in public spaces.\nExamples of representing our community include using an official e-mail address,\nposting via an official social media account, or acting as an appointed\nrepresentative at an online or offline event.","ref":"code_of_conduct.html#scope"},{"type":"extras","title":"Enforcement - Code of Conduct","doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be\nreported to the community leaders responsible for enforcement at\nengineering@therealreal.com. All complaints will be reviewed and investigated\npromptly and fairly.\n\nAll community leaders are obligated to respect the privacy and security of the\nreporter of any incident.","ref":"code_of_conduct.html#enforcement"},{"type":"extras","title":"Enforcement Guidelines - Code of Conduct","doc":"Community leaders will follow these Community Impact Guidelines in determining\nthe consequences for any action they deem in violation of this Code of Conduct:\n\n#","ref":"code_of_conduct.html#enforcement-guidelines"},{"type":"extras","title":"1. Correction - Code of Conduct","doc":"**Community Impact**: Use of inappropriate language or other behavior deemed\nunprofessional or unwelcome in the community.\n\n**Consequence**: A private, written warning from community leaders, providing\nclarity around the nature of the violation and an explanation of why the\nbehavior was inappropriate. A public apology may be requested.\n\n#","ref":"code_of_conduct.html#1-correction"},{"type":"extras","title":"2. Warning - Code of Conduct","doc":"**Community Impact**: A violation through a single incident or series of\nactions.\n\n**Consequence**: A warning with consequences for continued behavior. No\ninteraction with the people involved, including unsolicited interaction with\nthose enforcing the Code of Conduct, for a specified period of time. This\nincludes avoiding interactions in community spaces as well as external channels\nlike social media. Violating these terms may lead to a temporary or permanent\nban.\n\n#","ref":"code_of_conduct.html#2-warning"},{"type":"extras","title":"3. Temporary Ban - Code of Conduct","doc":"**Community Impact**: A serious violation of community standards, including\nsustained inappropriate behavior.\n\n**Consequence**: A temporary ban from any sort of interaction or public\ncommunication with the community for a specified period of time. No public or\nprivate interaction with the people involved, including unsolicited interaction\nwith those enforcing the Code of Conduct, is allowed during this period.\nViolating these terms may lead to a permanent ban.\n\n#","ref":"code_of_conduct.html#3-temporary-ban"},{"type":"extras","title":"4. Permanent Ban - Code of Conduct","doc":"**Community Impact**: Demonstrating a pattern of violation of community\nstandards, including sustained inappropriate behavior, harassment of an\nindividual, or aggression toward or disparagement of classes of individuals.\n\n**Consequence**: A permanent ban from any sort of public interaction within the\ncommunity.","ref":"code_of_conduct.html#4-permanent-ban"},{"type":"extras","title":"Attribution - Code of Conduct","doc":"This Code of Conduct is adapted from the [Contributor Covenant][homepage],\nversion 2.1, available at\n[https://www.contributor-covenant.org/version/2/1/code_of_conduct.html][v2.1].\n\nCommunity Impact Guidelines were inspired by\n[Mozilla's code of conduct enforcement ladder][Mozilla CoC].\n\nFor answers to common questions about this code of conduct, see the FAQ at\n[https://www.contributor-covenant.org/faq][FAQ]. Translations are available at\n[https://www.contributor-covenant.org/translations][translations].\n\n[homepage]: https://www.contributor-covenant.org\n[v2.1]: https://www.contributor-covenant.org/version/2/1/code_of_conduct.html\n[Mozilla CoC]: https://github.com/mozilla/diversity\n[FAQ]: https://www.contributor-covenant.org/faq\n[translations]: https://www.contributor-covenant.org/translations","ref":"code_of_conduct.html#attribution"}],"content_type":"text/markdown"}